==> haskell-casa-client-0.0.2-36-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-client
version:              0.0.2
visibility:           public
id:                   casa-client-0.0.2-HXViWHv7ODnCVWQdsM5kNh
key:                  casa-client-0.0.2-HXViWHv7ODnCVWQdsM5kNh
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Client for Casa
description:          Client for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  ea2c8eb83674d4427d10bec6816becfd
exposed:              True
exposed-modules:      Casa.Client
hidden-modules:       Paths_casa_client
import-dirs:          /usr/lib/ghc-9.4.8/site-local/casa-client-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/casa-client-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/casa-client-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-client
hs-libraries:         HScasa-client-0.0.2-HXViWHv7ODnCVWQdsM5kNh
depends:
    aeson-2.1.2.1-41nZsNdpCJ94QO3IYYsFbV
    attoparsec-0.14.4-6t7vY6Q8UUxCr7xgApY0J0 base-4.17.2.1
    base16-bytestring-1.0.2.0-2g7vQYppoMG2r37VyquVQT
    bytestring-0.11.5.3 casa-types-0.0.2-AXIUM7n6bCw3JpWlMo4jXE
    conduit-1.3.6.1-4J0p2y8YZbl5jbLvhSkgCv
    conduit-extra-1.3.7-Ajk39DYeR8SCitLkHBuvyO
    crypton-1.0.0-JfIgPQAzFRT4SOZzJiW3sj exceptions-0.10.5
    http-conduit-2.3.9.1-GzC96qBuvDU7sUI5g556at
    http-types-0.12.4-4HneWdIW87FoB16iA969W
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-uri-2.6.4.2-5qu1Opa5LrJOaefG2BKZh
    resourcet-1.2.6-HOcTeGTfW655uDg0bvoLZW template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-1XH4GFhGkAzqDGOzdhg7S

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-casa-client-0.0.2-37-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-casa-client.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 casa-client
version:              0.0.2
visibility:           public
id:                   casa-client-0.0.2-52zkIN3xE4iA6eeM5d6xMd
key:                  casa-client-0.0.2-52zkIN3xE4iA6eeM5d6xMd
license:              BSD-3-Clause
copyright:            2018-2019 FP Complete
maintainer:           chrisdone@fpcomplete.com
author:               Chris Done
synopsis:             Client for Casa
description:          Client for Casa <https://casa.fpcomplete.com/>
category:             Development
abi:                  876c4d3d79b56a0fde12327b1673ebc8
exposed:              True
exposed-modules:      Casa.Client
hidden-modules:       Paths_casa_client
import-dirs:          /usr/lib/ghc-9.4.8/site-local/casa-client-0.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/casa-client-0.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/casa-client-0.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-casa-client
hs-libraries:         HScasa-client-0.0.2-52zkIN3xE4iA6eeM5d6xMd
depends:
    aeson-2.1.2.1-1sit77W6SL3BciMFQH0A5E
    attoparsec-0.14.4-6t7vY6Q8UUxCr7xgApY0J0 base-4.17.2.1
    base16-bytestring-1.0.2.0-2g7vQYppoMG2r37VyquVQT
    bytestring-0.11.5.3 casa-types-0.0.2-BcWGZQsZ38pDcNMdafzFNJ
    conduit-1.3.6.1-2ALTHKVWE9PHUS8ksnDgpr
    conduit-extra-1.3.7-8SvbBd5t3V7KSlP9Oy8qXQ
    crypton-1.0.0-JfIgPQAzFRT4SOZzJiW3sj exceptions-0.10.5
    http-conduit-2.3.9.1-oX6nWmxlNdBzGwryOCGOM
    http-types-0.12.4-ETM4Wt9wTb3IJwpuKYvfG2
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-uri-2.6.4.2-3kbcHDwZ6x6AGz5jhfsmNJ
    resourcet-1.2.6-Hgo6O7VyL9xLXRmliBnYwI template-haskell-2.19.0.0
    text-2.0.2 th-lift-0.8.5-3bCWMcLwp8dEXoRnv4Yrhx
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    unordered-containers-0.2.20-1q9sqpstxGlGEsMEnuqYMK

haddock-interfaces:   /usr/share/doc/haskell-casa-client/html/casa-client.haddock
haddock-html:         /usr/share/doc/haskell-casa-client/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
